---
title: Kiosk Einrichtung
weight: 2
prev: /kiosk
next: /kiosk/config
lang: de
---

So richten Sie den Kiosk für die Veranstaltung ein.

## Mit Windows Assigned Access

{{< callout type="info" >}}
    Dies wurde nur auf Windows 11 Pro und Enterprise getestet.
{{< /callout >}}

### Voraussetzungen

- Windows 11 Pro oder Enterprise
- Nur ein konfigurierter Drucker oder Belegdrucker als Standarddrucker eingerichtet - du kannst die Druckfunktion deaktivieren, aber mit Drucker ist die Benutzererfahrung besser
- Administratorzugriff auf das System

### Einrichtung

1. Laden Sie [psexec](/files/psexec.exe) herunter
2. Öffnen Sie eine PowerShell mit Administratorrechten
3. Wechseln Sie zum Download-Ordner `cd C:\Users\<Benutzername>\Downloads`
4. Führe den psexec-Befehl aus: `.\psexec.exe -i -s powershell.exe`
5. Führe das folgende Skript aus

    {{< tabs items="Mit Drucker, Ohne Drucker" >}}

    {{< tab >}}
    ```powershell
    $assignedAccessConfiguration = @"
    <?xml version="1.0" encoding="utf-8"?>
    <AssignedAccessConfiguration xmlns="http://schemas.microsoft.com/AssignedAccess/2017/config" xmlns:rs5="http://schemas.microsoft.com/AssignedAccess/201810/config" xmlns:v4="http://schemas.microsoft.com/AssignedAccess/2021/config">
    <Profiles>
        <Profile Id="{EDB3036B-780D-487D-A375-69369D8A8F78}">
        <KioskModeApp v4:ClassicAppPath="%ProgramFiles(x86)%\Microsoft\Edge\Application\msedge.exe" v4:ClassicAppArguments="--kiosk https://kiosk.lauf-fuer-kaya.de/?print=true --kiosk-printing --edge-kiosk-type=fullscreen" />
        <v4:BreakoutSequence Key="Ctrl+E" />
        </Profile>
    </Profiles>
    <Configs>
        <Config>
        <AutoLogonAccount rs5:DisplayName="Lfk Kiosk" />
        <DefaultProfile Id="{EDB3036B-780D-487D-A375-69369D8A8F78}" />
        </Config>
    </Configs>
    </AssignedAccessConfiguration>
    "@

    $namespaceName="root\cimv2\mdm\dmmap"
    $className="MDM_AssignedAccess"
    $obj = Get-CimInstance -Namespace $namespaceName -ClassName $className
    $obj.Configuration = [System.Net.WebUtility]::HtmlEncode($assignedAccessConfiguration)
    Set-CimInstance -CimInstance $obj
    ```
    {{< /tab >}}
    {{< tab >}}
    ```powershell
    $assignedAccessConfiguration = @"
    <?xml version="1.0" encoding="utf-8"?>
    <AssignedAccessConfiguration xmlns="http://schemas.microsoft.com/AssignedAccess/2017/config" xmlns:rs5="http://schemas.microsoft.com/AssignedAccess/201810/config" xmlns:v4="http://schemas.microsoft.com/AssignedAccess/2021/config">
    <Profiles>
        <Profile Id="{EDB3036B-780D-487D-A375-69369D8A8F78}">
        <KioskModeApp v4:ClassicAppPath="%ProgramFiles(x86)%\Microsoft\Edge\Application\msedge.exe" v4:ClassicAppArguments="--kiosk https://kiosk.lauf-fuer-kaya.de/ --kiosk-printing --edge-kiosk-type=fullscreen" />
        <v4:BreakoutSequence Key="Ctrl+E" />
        </Profile>
    </Profiles>
    <Configs>
        <Config>
        <AutoLogonAccount rs5:DisplayName="Lfk Kiosk" />
        <DefaultProfile Id="{EDB3036B-780D-487D-A375-69369D8A8F78}" />
        </Config>
    </Configs>
    </AssignedAccessConfiguration>
    "@

    $namespaceName="root\cimv2\mdm\dmmap"
    $className="MDM_AssignedAccess"
    $obj = Get-CimInstance -Namespace $namespaceName -ClassName $className
    $obj.Configuration = [System.Net.WebUtility]::HtmlEncode($assignedAccessConfiguration)
    Set-CimInstance -CimInstance $obj
    ```
    {{< /tab >}}
    {{< /tabs >}}

6. Ruhezustand und Windows Tastenkombinationen deaktivieren

   ```powershell
   $NullKey        = [byte[]]($null,$null)
   $LeftWindows    = [byte[]](0x5b,0xe0)
   $RightWindows   = [byte[]](0x5c,0xe0)
   
   $RemapCount     = 2
   
   $ReMap          = [byte[]](
                             [Byte[]]::new(8) +
      [BitConverter]::GetBytes(1+$RemapCount) +
                      $NullKey + $LeftWindows +
                     $NullKey + $RightWindows +
                             [Byte[]]::new(4)
   )
   
   $Splat = @{
       'Path'  = 'HKLM:\SYSTEM\CurrentControlSet\Control\Keyboard Layout'
       'Name'  = 'ScanCode Map'
       'Value' = $Remap
       'Force' = $True
   }
   New-ItemProperty @Splat

   $RegistryPath = "HKLM:\SOFTWARE\Policies\Microsoft\Dsh"
   $Name = "AllowNewsAndInterests"
   $Value = 0
   
   If (-not (Test-Path $RegistryPath)) {
       New-Item -Path $RegistryPath -Force | Out-Null
   }
   
   New-ItemProperty -Path $RegistryPath -Name $Name -Value $Value -Type DWORD -Force | Out-Null

   powercfg.exe -x -monitor-timeout-ac 0
   powercfg.exe -x -monitor-timeout-dc 0
   powercfg.exe -x -disk-timeout-ac 0
   powercfg.exe -x -disk-timeout-dc 0
   powercfg.exe -x -standby-timeout-ac 0
   powercfg.exe -x -standby-timeout-dc 0
   powercfg.exe -x -hibernate-timeout-ac 0
   powercfg.exe -x -hibernate-timeout-dc 0
   ```

7. Nur für den Druck: Druck ohne Metadaten einrichten:
    1. Lade die [Administrativen Richtlinienvorlagen für Edge](https://www.microsoft.com/de-de/edge/business/download) herunter (Neueste Version herunterladen -> Windows 64-bit -> Windows 64-bit-Richtlinie herunterladen)
    2. Kopiere den Inhalt der ZIP-Datei aus dem `.cab`-Archiv nach `C:\Windows\PolicyDefinitions`.
    3. Öffne den Gruppenrichtlinien-Editor (GPEdit) und navigiere zu `Computerkonfiguration -> Administrative Vorlagen -> Microsoft Edge -> Drucken`
    4. Öffne die Richtlinie `Kopf- und Fußzeilen drucken`, setze sie auf `Deaktiviert` und klicke auf `OK`.

8. Neustarten via `shutdown -r -t 0` oder die Windows Benutzeroberfläche.

### Deinstallation

1. Um den Kiosk-Modus zu verlassen, drücken Sie `Strg+E`
2. Öffnen Sie eine PowerShell mit Administratorrechten
3. Wechseln Sie zum Desktop-Ordner (C:\Users\<Benutzername>\Desktop)
4. Führen Sie den psexec-Befehl aus: `psexec.exe -i -s powershell.exe`
5. Führen Sie das folgende Skript aus

   ```powershell
   $namespaceName="root\cimv2\mdm\dmmap"
   $className="MDM_AssignedAccess"
   $obj = Get-CimInstance -Namespace $namespaceName -ClassName $className
   $obj.Configuration = $null
   Set-CimInstance -CimInstance $obj
   $Splat = @{
       'Path'  = 'HKLM:\SYSTEM\CurrentControlSet\Control\Keyboard Layout'
       'Name'  = 'ScanCode Map'
       'Force' = $True
   }   
   Remove-ItemProperty @Splat   
   $RegistryPath = "HKLM:\SOFTWARE\Policies\Microsoft\Dsh"
   $Name = "AllowNewsAndInterests"
   If (Test-Path -Path $RegistryPath) {
       If (Get-ItemProperty -Path $RegistryPath -Name $Name -ErrorAction       SilentlyContinue) {
           Remove-ItemProperty -Path $RegistryPath -Name $Name -Force |   Out-Null
       }
   }
   ```

## Mit deinem bevorzugten Browser

{{< callout type="warning" >}}
    Die Möglichkeit, den Browser zu verlassen und/oder DevTools zu öffnen, könnte standardmäßig verfügbar sein.
    Bitte prüfe, ob dein Browser einen Kiosk-Modus unterstützt und wie du ihn einrichten kannst.
{{< /callout >}}
{{< callout type="warning" >}}
    Dein Browser unterstützt möglicherweise nicht das Drucken ohne Dialog.
    Bitte prüfe, ob dein Browser diese Funktion unterstützt und wie du sie einrichten kannst.
{{< /callout >}}

Öffne einfach den Link in deinem bevorzugten Browser und nutze den Kiosk-Modus deines Browsers:
- Mit automatischem Druck: <https://kiosk.lauf-fuer-kaya.de/?print=true>
- Ohne automatischen Druck: <https://kiosk.lauf-fuer-kaya.de/>
